@@ -27,7 +27,8 @@ class TitansMemoryAdapter:
         self.config = config or {}
         
         # Initialize Titans memory with configuration
-        memory_dir = os.path.join(os.path.dirname(os.path.dirname(os.path.abspath(__file__))), "titans")
+        # Use current working directory for memory storage instead of package directory
+        memory_dir = os.path.join(os.getcwd(), "memory", "titans")
         os.makedirs(memory_dir, exist_ok=True)
         
         self.titans_memory = TitansInspiredMemory(
